<?php
​
class Roistat {
    const KEY     = '';
    const PROJECT = '';
​
    /**
     * @param array $phoneData
     * @return string
     * @throws Exception
     */
    public function createPhoneCall(array $phoneData = []) {
        if (!array_key_exists('callee', $phoneData) || !array_key_exists('caller', $phoneData) || !array_key_exists('date', $phoneData)) {
            throw new Exception("Поля callee, caller и date обязательны для создания нового звонка");
        }
​
        return $this->curlSend('project/phone-call', array(
            "callee"          => trim($phoneData['callee']),
            "caller"          => trim($phoneData['caller']),
            "date"            => date('c', strtotime($phoneData['date'])),
            "duration"        => null,
            "order_id"        => null,
            "save_to_crm"     => "1",
            "status"          => $phoneData['status'],
            "comment"         => null,
            "answer_duration" => null,
        ));
    }
​
    /**
     * @param array $phoneData
     * @return string
     * @throws Exception
     */
    public function updatePhoneCall(array $phoneData = []) {
        if (!array_key_exists('id', $phoneData)) {
            throw new Exception("Поле id обязательно для обновления звонка");
        }
​
        return $this->curlSend('project/calltracking/call/update', array(
            "id"       => $phoneData['id'],
            "status"   => $phoneData['status'],
            "duration" => $phoneData['duration'],
            "link"     => $phoneData['link'],
        ));
    }
​
    /**
     * @param string $phone
     * @return string
     * @throws Exception
     */
    public function phoneList($phone) {
        if (empty($phone)) {
            throw new Exception("Номер телефона пустой");
        }
​
        $result = $this->curlSend('project/calltracking/call/list', array(
            array(
                'filters' => array(
                    array(
                        'caller',
                        '=',
                        $phone,
                    ),
                ),
                'extend' => array(
                    'visit',
                ),
                'sort' => array(
                    'date',
                    'desc',
                ),
                'limit' => 1,
                'offset' => 0,
            )
        ));
​
        return json_decode($result, true);
    }
​
    /**
     * @param string $url
     * @param array $param
     * @return string
     * @throws Exception
     */
    private function curlSend($url, array $param = []) {
        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL            => "https://cloud.roistat.com/api/v1/{$url}?key=".self::KEY."&project=".self::PROJECT,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING       => "",
            CURLOPT_MAXREDIRS      => 10,
            CURLOPT_TIMEOUT        => 30,
            CURLOPT_HTTP_VERSION   => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST  => "POST",
            CURLOPT_POSTFIELDS     => json_encode($param),
            CURLOPT_HTTPHEADER     => array("content-type: application/json"),
        ));
​
        $response = curl_exec($curl);
        $err      = curl_error($curl);
​
        curl_close($curl);
​
        if ($err) {
            throw new Exception("cURL Error #:" . $err);
        } else {
            return json_encode($response, true);
        }
    }
}